--[[
--Copyright 2015-2017 O. Bahri Gordebak
--with code kindly contributed by 4aiman https://4aiman.itch.io 
--]]

local windpart = love.graphics.newImage("images/wind.png")
local particles = love.graphics.newParticleSystem(windpart, 10000)
particles:setParticleLifetime(20)
particles:setEmissionRate(100)
particles:setSizes(0.5, 2)
particles:setSizeVariation(1)
particles:setSpin(0, 10)
particles:setSpinVariation(1)
particles:setColors(255, 255, 255, 255, 255, 255, 255, 0)
particles:setAreaSpread("uniform", 500, 500 )
particles:setSpeed(50)
particles:stop()

function love.load()
    love.graphics.setBackgroundColor(0,0,0)
    love.graphics.setNewFont(16)
    love.window.setMode( 800, 600, {fullscreen=false} )
    love.window.setTitle( "Simple Collision" )
    love.mouse.setVisible( true )
    math.randomseed(os.time())
    math.random(8)
    x = 375
    y = 275
    velx = 0
    vely = 0
    time = 0
    ttime = 0
    start = true
    dead = false
    force = 0
    old_force = 0
    sound = true
    imageUp = love.graphics.newImage("images/up.png")
    imageDown = love.graphics.newImage("images/down.png")
    imageRight = love.graphics.newImage("images/right.png")
    imageLeft = love.graphics.newImage("images/left.png")
    imageUpRight = love.graphics.newImage("images/upright.png")
    imageUpLeft = love.graphics.newImage("images/upleft.png")
    imageDownRight = love.graphics.newImage("images/downright.png")
    imageDownLeft = love.graphics.newImage("images/downleft.png")
    images = {imageDownRight, imageDown, imageDownLeft, imageLeft, imageUpLeft, imageUp, imageUpRight, imageRight}
    music = love.audio.newSource("sounds/goofymusic.mp3")
    music:setLooping(1)
    music:play()
    forced = ""
    wave = 50
    bonus = 0
end

function love.keyreleased(key)
    if key == "m" then
        if sound then
            sound = false
            music:stop()
        else
            sound = true
            music:play()
        end
    end
end

function love.update(dt)

    time = time + dt

    if not dead then
       ttime = ttime + dt*(bonus+1)
    end
    
    
    if time> math.max(50/wave, 2) then
       time = 0
       force = math.random(8)
    end

    int,frac = math.modf(time)
    int = int / 2
    if love.keyboard.isDown("escape") then
        love.event.push("quit")
    end    
    if force > 0 then
        if force == 5 then
            velx = -(80 + int) * dt * wave/100
            vely = -(80 + int) * dt * wave/100
            forced = "UL"
        elseif force == 6 then
            velx = 0
            vely = -(80 + int) * dt * wave/100
            forced = "UP"
        elseif force == 7 then
            velx = (80 + int) * dt * wave/100
            vely = -(80 + int) * dt * wave/100
            forced = "UR"
        elseif force == 4 then
            velx = -(80 + int) * dt * wave/100
            vely = 0
            forced = "LT"
        elseif force == 8 then
            velx = (80 + int) * dt * wave/100
            vely = 0
            forced = "RT"
        elseif force == 3 then
            velx = -(80 + int) *dt * wave/100
            vely = (80 + int) * dt * wave/100
            forced = "BL"
        elseif force == 2 then
            velx = 0
            vely = (80 + int) * dt * wave/100
            forced = "BT"
        elseif force == 1 then
            velx = (80 + int) * dt * wave/100
            vely = (80 + int) * dt * wave/100
            forced = "BR"
        end
    end

    if not start then
        if love.keyboard.isDown("right") then
            velx = velx + ((120 + int) * dt * wave/100)
        end
        if love.keyboard.isDown("left") then
            velx = velx + (-(120 + int) * dt * wave/100)
        end
        if love.keyboard.isDown("up") then
            vely = vely + (-(120 + int) * dt * wave/100)
        end
        if love.keyboard.isDown("down") then
            vely = vely + ((120 + int) * dt * wave/100)
        end
    end
    if love.keyboard.isDown("space") and dead then
        x = 375
        y = 275
        velx = 0
        vely = 0
        time = 0
        dead = false
        force = math.random(8)
        particles:start()
        ttime = 0
    end
    if love.keyboard.isDown("space") and start then
        start = false
        force = math.random(8)
        particles:start()
    end
    if x < 275 or x > 475 or y < 175 or y > 375 then
        velx = 0
        vely = 0
        dead = true
    end

    
    if x < 325 or x > 425 or y < 225 or y > 325 then
       get_bonus = false
    end

    x = x + velx
    y = y + vely

    if old_force~=force then
       wave = wave + bonus+1
       old_force = force
       local angle = force*(360/8)
       particles:setDirection(math.rad(angle))
       particles:setSpeed(wave)
       particles:reset()
       if get_bonus then
          bonus = bonus + 1
       else
          get_bonus = true
          bonus = 0
       end        
    end

    if dead then
       wave = 50
       bonus = 0
       particles:stop()
    end

    particles:update(dt)

end

function love.draw()
    love.graphics.setColor(255, 255, 255)
    love.graphics.setColor(0, 0, 255)
    love.graphics.rectangle("line", 275, 175, 250, 250)
    love.graphics.setColor(0, 100, 255)
    love.graphics.rectangle("line", 325, 225, 150, 150)
    if start then
        love.graphics.setColor(255, 255, 255)
        love.graphics.print("Press Space to start", 10, 30)
    else
        if dead then
            love.graphics.setColor(255, 0, 0)
            love.graphics.rectangle("fill", x, y, 50, 50)
            love.graphics.setColor(255, 255, 255)
            love.graphics.print("You survived "..(math.floor(ttime*100)/100).." seconds.", 10, 30)
            love.graphics.print("Press Space to start again.", 10, 50)        
        else
            love.graphics.setColor(0,255,0)
            love.graphics.rectangle("fill", x, y, 50, 50)
            love.graphics.setColor(205,205,0)
            love.graphics.print("Bonus: x"..bonus, 10, 550)

            if bonus>0 then
               love.graphics.setColor(255,205,055)
               love.graphics.print((math.floor(ttime*100)/100), 10, 10, math.rad(math.random(0,bonus)/1))
            else
               love.graphics.setColor(255,255,255)
               love.graphics.print((math.floor(ttime*100)/100), 10, 10)
            end            
        end
    end
    love.graphics.setColor(255,255,255)
    if sound then
        love.graphics.print("(M)usic on", 680, 10)
    else
        love.graphics.print("(M)usic off", 680, 10)
    end
    
    
    for i=1,8 do
        local angle = i*(360/8)
 	    local x = 220 * math.cos(math.rad(angle)) + 370
		local y = 220 * math.sin(math.rad(angle)) + 265
        --love.graphics.print(i.." "..forced.." ("..force..")",x,y)
        if force ~=i then
           love.graphics.setColor(0, 150, 0)
           love.graphics.draw(images[i], x, y)
        else           
           love.graphics.setColor(200, 0, 0)
           love.graphics.draw(images[i], x+math.random(-4,4), y+math.random(-4,4))
        end
    end

    love.graphics.setColor(255, 255, 255)
	love.graphics.draw(particles, 400, 300)

end
